@@ -7,6 +7,11 @@
 #
 
 package POE::Component::Client::NNTP;
+BEGIN {
+  $POE::Component::Client::NNTP::VERSION = '2.20';
+}
+
+# ABSTRACT: A POE component that implements an RFC 3977 NNTP client.
 
 use 5.006;
 use strict;
@@ -17,9 +22,6 @@ use Carp;
 use Socket;
 use base qw(POE::Component::Pluggable);
 use POE::Component::Pluggable::Constants qw(:ALL);
-use vars qw($VERSION);
-
-$VERSION = '2.18';
 
 our ($GOT_SSL,$GOT_SOCKET6);
 
@@ -41,6 +43,7 @@ sub spawn {
   my $package_events = {};
 
   $package_events->{$_} = '_accept_input' for qw(article body head stat group help ihave last list newgroups newnews next post quit slave authinfo);
+  $package_events->{$_} = '_accept_input' for qw(capabilities listgroup date over hdr);
 
   croak "Not enough parameters to $package::spawn()" unless $alias;
   croak "Second argument to $package::spawn() must be a hash reference" unless ref $hash eq 'HASH';
@@ -149,6 +152,7 @@ sub _start {
     $kernel->refcount_increment($sender_id, __PACKAGE__);
     $kernel->post( $sender, 'nntp_registered', $self );
   }
+  $self->{cmd_queue} = [];
   $self->{connected} = 0;
   undef;
 }
@@ -253,6 +257,8 @@ sub _sock_failed {
 sub _parseline {
   my ($kernel, $session, $self, $line) = @_[KERNEL, SESSION, OBJECT, ARG0];
 
+  my $cmd = shift @{ $self->{cmd_queue} };
+
   $kernel->delay( '_timeout' );
 
   SWITCH: {
@@ -264,7 +270,8 @@ sub _parseline {
     }
     if ( $line =~ /^([0-9]{3}) +(.+)$/ and !defined $self->{current_event} ) {
       my $current_event = [ $1, $2 ];
-      if ( $1 =~ /(220|221|222|100|215|231|230|211|282|218|224)/ ) {
+      # 211 is special GROUP and LISTGROUP generate it and it can single or multi-line
+      if ( ( $1 eq '211' and lc $cmd eq 'listgroup' ) or $1 =~ /(100|101|220|221|222|225|215|231|230|282|218|224)/ ) {
         $self->{current_event} = $current_event;
         $self->{current_text} = [ ];
       } 
@@ -328,6 +335,7 @@ sub send_cmd {
   my $arg = join ' ', @_[ARG0 .. $#_];
   return 1 if $self->_pluggable_process( 'NNTPCMD', 'send_cmd', \$arg ) == PLUGIN_EAT_ALL;
   if ( defined $self->{socket} ) {
+    push @{ $self->{cmd_queue} }, lc( ( split /\s+/, $arg )[0] );
     $self->{socket}->put($arg);
     $kernel->delay( '_timeout', $self->{timeout} ) if $self->{timeout};
   }
@@ -339,6 +347,7 @@ sub _accept_input {
   my $arg = join ' ', @_[ARG0 .. $#_];
   return 1 if $self->_pluggable_process( 'NNTPCMD', $state, \$arg ) == PLUGIN_EAT_ALL;
   if ( defined $self->{socket} ) {
+    push @{ $self->{cmd_queue} }, lc $state;
     $self->{socket}->put("$state $arg");
     $kernel->delay( '_timeout', $self->{timeout} ) if $self->{timeout};
   }
@@ -355,11 +364,18 @@ sub send_post {
 }
 
 1;
+
+
 __END__
+=pod
 
 =head1 NAME
 
-POE::Component::Client::NNTP - A POE component that implements an RFC 977 NNTP client.
+POE::Component::Client::NNTP - A POE component that implements an RFC 3977 NNTP client.
+
+=head1 VERSION
+
+version 2.20
 
 =head1 SYNOPSIS
 
@@ -460,11 +476,10 @@ POE::Component::Client::NNTP - A POE component that implements an RFC 977 NNTP c
 	undef;
    }
 
-
 =head1 DESCRIPTION
 
 POE::Component::Client::NNTP is a POE component that provides non-blocking NNTP access to other
-components and sessions. NNTP is described in RFC 977 L<http://www.faqs.org/rfcs/rfc977.html>, 
+components and sessions. NNTP is described in RFC 3977 L<http://www.faqs.org/rfcs/rfc3977.html>, 
 please read it before doing anything else.
 
 In your component or session, you spawn a NNTP client component, assign it an alias, and then 
@@ -552,7 +567,7 @@ Always ensure that you call C<unregister> before shutting down the component.
 
 =back
 
-The following are implemented NNTP commands, check RFC 977 L<http://www.faqs.org/rfcs/rfc977.html> for the arguments accepted by each. Arguments can be passed as a single scalar or a list of arguments:
+The following are implemented NNTP commands, check RFC 3977 L<http://www.faqs.org/rfcs/rfc3977.html> for the arguments accepted by each. Arguments can be passed as a single scalar or a list of arguments:
 
 =over
 
@@ -620,10 +635,32 @@ Takes no arguments.
 
 Takes no arguments.
 
+=item C<capabilities>
+
+Returns a list of capabilities.
+
+=item C<listgroup>
+
+Provides a list of article numbers in a group.
+
+=item C<date>
+
+Find out the current Coordinated Universal Time
+
+=item C<over>
+
+The OVER command returns the contents of all the fields in the
+database for an article specified by message-id.
+
+=item C<hdr>
+
+The HDR command provides access to specific fields from an article
+specified by message-id.
+
 =item C<authinfo>
 
 Takes two arguments: first argument is either C<user> or C<pass>, second argument is the user or password, respectively. 
-Not technically part of RFC 977 L<http://www.faqs.org/rfcs/rfc977.html>, but covered in RFC 2980 L<http://www.faqs.org/rfcs/rfc2980.html>.
+Not technically part of RFC 3977 L<http://www.faqs.org/rfcs/rfc3977.html>, but covered in RFC 2980 L<http://www.faqs.org/rfcs/rfc2980.html>.
 
 =item C<send_cmd>
 
@@ -691,17 +728,20 @@ Possible nntp_ values are:
    205 closing connection - goodbye!
    211 n f l s group selected
    215 list of newsgroups follows
-   220 n <a> article retrieved - head and body follow 221 n <a> article
-   retrieved - head follows
+   220 n <a> article retrieved - head and body follow
+   221 n <a> article retrieved - head follows
    222 n <a> article retrieved - body follows
-   223 n <a> article retrieved - request text separately 230 list of new
-   articles by message-id follows
+   223 n <a> article retrieved - request text separately
+   230 list of new articles by message-id follows
    231 list of new newsgroups follows
    235 article transferred ok
    240 article posted ok
+   250 authentication accepted, successful authentication using the AUTHINFO command extension.
+   281 authentication accepted, successful authentication using the AUTHINFO command extension.
 
    335 send article to be transferred.  End with <CR-LF>.<CR-LF>
    340 send article to be posted. End with <CR-LF>.<CR-LF>
+   381 more authentication information required, preliminary response to the AUTHINFO command extension.
 
    400 service discontinued
    411 no such news group
@@ -757,7 +797,7 @@ with the following line:
 
 The return values have the following significance:
 
-=over 
+=over
 
 =item C<NNTP_EAT_NONE>
 
@@ -932,18 +972,6 @@ The basic anatomy of a plugin is:
 
 The group event sets the current working group on the server end. If you want to use group and numeric form of article|head|etc then you will have to spawn multiple instances of the component for each group you want to access concurrently.
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams, E<lt>chris@bingosnet.co.uk<gt>
-
-With code derived from L<POE::Component::IRC> by Dennis Taylor.
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams and Dennis Taylor.
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 RFC 977  L<http://www.faqs.org/rfcs/rfc977.html>
@@ -952,4 +980,16 @@ RFC 2980 L<http://www.faqs.org/rfcs/rfc2980.html>
 
 L<POE::Component::Pluggable>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Chris Williams and Dennis Taylor.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
