@@ -1,10 +1,12 @@
 package POE::Component::Client::NNTP::Constants;
+BEGIN {
+  $POE::Component::Client::NNTP::Constants::VERSION = '2.20';
+}
+
+# ABSTRACT: importable constants for POE::Component::Client::NNTP plugins.
 
 use strict;
 use warnings;
-use vars qw($VERSION);
-
-$VERSION = '2.12';
 
 require Exporter;
 our @ISA = qw( Exporter );
@@ -18,12 +20,19 @@ sub NNTP_EAT_PLUGIN	() { 3 }
 sub NNTP_EAT_ALL	() { 4 }
 
 1;
+
+
 __END__
+=pod
 
 =head1 NAME
 
 POE::Component::Client::NNTP::Constants - importable constants for POE::Component::Client::NNTP plugins.
 
+=head1 VERSION
+
+version 2.20
+
 =head1 SYNOPSIS
 
   use POE::Component::Client::NNTP::Constants qw(:ALL);
@@ -54,20 +63,22 @@ Value: 4
 
 =back
 
-=head1 MAINTAINER
-
-Chris 'BinGOs' Williams <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams.
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE::Component::Client::NNTP>
 
 L<POE::Component::Pluggable>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Chris Williams and Dennis Taylor.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
